@@ -1,41 +1,58 @@
-"""
-    Change directory to provide relative paths for doctests
-    >>> import os
-    >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
-    >>> datadir = os.path.realpath(os.path.join(filepath, '../../testing/data'))
-    >>> os.chdir(datadir)
+# -*- coding: utf-8 -*-
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
-"""
 import os
 
-from nipype.interfaces.base import (CommandLineInputSpec, CommandLine, traits,
-                                    TraitedSpec, File, StdOutCommandLine,
-                                    StdOutCommandLineInputSpec, isdefined)
-from nipype.utils.filemanip import split_filename
+from ...utils.filemanip import split_filename
+from ..base import (traits, TraitedSpec, File, StdOutCommandLine,
+                    StdOutCommandLineInputSpec)
+
 
 class QBallMXInputSpec(StdOutCommandLineInputSpec):
-    basistype = traits.Enum('rbf', 'sh', argstr='-basistype %s',
-                             desc=('Basis function type. "rbf" to use radial basis functions '
-                                  '"sh" to use spherical harmonics'), usedefault=True)
-    scheme_file = File(exists=True, argstr='-schemefile %s', mandatory=True,
-                       desc='Specifies the scheme file for the diffusion MRI data')
-    order = traits.Int(argstr='-order %d', units='NA',
-                             desc=('Specific to sh. Maximum order of the spherical harmonic series. '
-                                   'Default is 4.'))
-    rbfpointset = traits.Int(argstr='-rbfpointset %d', units='NA',
-                             desc=('Specific to rbf. Sets the number of radial basis functions to use. '
-                                   'The value specified must be present in the Pointsets directory. '
-                                   'The default value is 246.'))
-    rbfsigma = traits.Float(argstr='-rbfsigma %f', units='NA',
-                            desc=('Specific to rbf. Sets the width of the interpolating basis functions. '
-                                  'The default value is 0.2618 (15 degrees).'))
-    smoothingsigma = traits.Float(argstr='-smoothingsigma %f', units='NA',
-                                  desc=('Specific to rbf. Sets the width of the smoothing basis functions. '
-                                        'The default value is 0.1309 (7.5 degrees).'))
+    basistype = traits.Enum(
+        'rbf',
+        'sh',
+        argstr='-basistype %s',
+        desc=('Basis function type. "rbf" to use radial basis functions '
+              '"sh" to use spherical harmonics'),
+        usedefault=True)
+    scheme_file = File(
+        exists=True,
+        argstr='-schemefile %s',
+        mandatory=True,
+        desc='Specifies the scheme file for the diffusion MRI data')
+    order = traits.Int(
+        argstr='-order %d',
+        units='NA',
+        desc=(
+            'Specific to sh. Maximum order of the spherical harmonic series. '
+            'Default is 4.'))
+    rbfpointset = traits.Int(
+        argstr='-rbfpointset %d',
+        units='NA',
+        desc=(
+            'Specific to rbf. Sets the number of radial basis functions to use. '
+            'The value specified must be present in the Pointsets directory. '
+            'The default value is 246.'))
+    rbfsigma = traits.Float(
+        argstr='-rbfsigma %f',
+        units='NA',
+        desc=
+        ('Specific to rbf. Sets the width of the interpolating basis functions. '
+         'The default value is 0.2618 (15 degrees).'))
+    smoothingsigma = traits.Float(
+        argstr='-smoothingsigma %f',
+        units='NA',
+        desc=(
+            'Specific to rbf. Sets the width of the smoothing basis functions. '
+            'The default value is 0.1309 (7.5 degrees).'))
+
 
 class QBallMXOutputSpec(TraitedSpec):
     qmat = File(exists=True, desc='Q-Ball reconstruction matrix')
 
+
 class QBallMX(StdOutCommandLine):
     """
     Generates a reconstruction matrix for Q-Ball. Used in LinRecon with
@@ -76,8 +93,8 @@ class QBallMX(StdOutCommandLine):
     >>> qballcoeffs.run()             # doctest: +SKIP
     """
     _cmd = 'qballmx'
-    input_spec=QBallMXInputSpec
-    output_spec=QBallMXOutputSpec
+    input_spec = QBallMXInputSpec
+    output_spec = QBallMXOutputSpec
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -85,29 +102,44 @@ class QBallMX(StdOutCommandLine):
         return outputs
 
     def _gen_outfilename(self):
-        _, name , _ = split_filename(self.inputs.scheme_file)
+        _, name, _ = split_filename(self.inputs.scheme_file)
         return name + '_qmat.Bdouble'
 
 
-
 class LinReconInputSpec(StdOutCommandLineInputSpec):
-    in_file = File(exists=True, argstr='%s', mandatory=True, position=1,
-                   desc='voxel-order data filename')
-    scheme_file = File(exists=True, argstr='%s', mandatory=True, position=2,
-                       desc='Specifies the scheme file for the diffusion MRI data')
-    qball_mat = File(exists=True, argstr='%s', mandatory=True, position=3,
-                     desc='Linear transformation matrix.')
-    normalize = traits.Bool(argstr='-normalize',
-                            desc=('Normalize the measurements and discard '
-                                  'the zero measurements before the linear transform.'))
-    log = traits.Bool(argstr='-log',
-                      desc=('Transform the log measurements rather than the '
-                            'measurements themselves'))
+    in_file = File(
+        exists=True,
+        argstr='%s',
+        mandatory=True,
+        position=1,
+        desc='voxel-order data filename')
+    scheme_file = File(
+        exists=True,
+        argstr='%s',
+        mandatory=True,
+        position=2,
+        desc='Specifies the scheme file for the diffusion MRI data')
+    qball_mat = File(
+        exists=True,
+        argstr='%s',
+        mandatory=True,
+        position=3,
+        desc='Linear transformation matrix.')
+    normalize = traits.Bool(
+        argstr='-normalize',
+        desc=('Normalize the measurements and discard '
+              'the zero measurements before the linear transform.'))
+    log = traits.Bool(
+        argstr='-log',
+        desc=('Transform the log measurements rather than the '
+              'measurements themselves'))
     bgmask = File(exists=True, argstr='-bgmask %s', desc='background mask')
 
+
 class LinReconOutputSpec(TraitedSpec):
     recon_data = File(exists=True, desc='Transformed data')
 
+
 class LinRecon(StdOutCommandLine):
     """
     Runs a linear transformation in each voxel.
@@ -152,8 +184,8 @@ class LinRecon(StdOutCommandLine):
     >>> qballcoeffs.run()         # doctest: +SKIP
     """
     _cmd = 'linrecon'
-    input_spec=LinReconInputSpec
-    output_spec=LinReconOutputSpec
+    input_spec = LinReconInputSpec
+    output_spec = LinReconOutputSpec
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -161,40 +193,76 @@ class LinRecon(StdOutCommandLine):
         return outputs
 
     def _gen_outfilename(self):
-        _, name , _ = split_filename(self.inputs.scheme_file)
+        _, name, _ = split_filename(self.inputs.scheme_file)
         return name + '_recondata.Bdouble'
 
+
 class MESDInputSpec(StdOutCommandLineInputSpec):
-    in_file = File(exists=True, argstr='-inputfile %s', mandatory=True, position=1,
-                   desc='voxel-order data filename')
-    inverter = traits.Enum('SPIKE', 'PAS', argstr='-filter %s', position=2, mandatory=True,
-                           desc=('The inversion index specifies the type of inversion to perform on the data.'
-                                 'The currently available choices are:'
-                                  'Inverter name  | Inverter parameters'
-                                  '---------------|------------------'
-                                  'SPIKE          | bd (b-value x diffusivity along the fibre.)'
-                                  'PAS            | r'))
-    inverter_param = traits.Float(argstr='%f', units='NA', position=3, mandatory=True,
-                                  desc=('Parameter associated with the inverter. Cf. inverter description for'
-                                        'more information.'))
-    fastmesd = traits.Bool(argstr='-fastmesd', requires=['mepointset'],
-                           desc=('Turns off numerical integration checks and fixes the integration point set size at that of'
-                                 'the index specified by -basepointset..'))
-    mepointset = traits.Int(argstr='-mepointset %d', units='NA',
-                            desc=('Use a set of directions other than those in the scheme file for the deconvolution kernel.'
-                                  'The number refers to the number of directions on the unit sphere. For example, '
-                                  '"-mepointset 54" uses the directions in "camino/PointSets/Elec054.txt".'))
-    scheme_file = File(exists=True, argstr='-schemefile %s', mandatory=True,
-                       desc='Specifies the scheme file for the diffusion MRI data')
+    in_file = File(
+        exists=True,
+        argstr='-inputfile %s',
+        mandatory=True,
+        position=1,
+        desc='voxel-order data filename')
+    inverter = traits.Enum(
+        'SPIKE',
+        'PAS',
+        argstr='-filter %s',
+        position=2,
+        mandatory=True,
+        desc=
+        ('The inversion index specifies the type of inversion to perform on the data.'
+         'The currently available choices are:'
+         'Inverter name  | Inverter parameters'
+         '---------------|------------------'
+         'SPIKE          | bd (b-value x diffusivity along the fibre.)'
+         'PAS            | r'))
+    inverter_param = traits.Float(
+        argstr='%f',
+        units='NA',
+        position=3,
+        mandatory=True,
+        desc=
+        ('Parameter associated with the inverter. Cf. inverter description for'
+         'more information.'))
+    fastmesd = traits.Bool(
+        argstr='-fastmesd',
+        requires=['mepointset'],
+        desc=
+        ('Turns off numerical integration checks and fixes the integration point set size at that of'
+         'the index specified by -basepointset..'))
+    mepointset = traits.Int(
+        argstr='-mepointset %d',
+        units='NA',
+        desc=
+        ('Use a set of directions other than those in the scheme file for the deconvolution kernel.'
+         'The number refers to the number of directions on the unit sphere. For example, '
+         '"-mepointset 54" uses the directions in "camino/PointSets/Elec054.txt".'
+         ))
+    scheme_file = File(
+        exists=True,
+        argstr='-schemefile %s',
+        mandatory=True,
+        desc='Specifies the scheme file for the diffusion MRI data')
     bgmask = File(exists=True, argstr='-bgmask %s', desc='background mask')
-    inputdatatype = traits.Enum('float', 'char', 'short', 'int', 'long', 'double', argstr='-inputdatatype %s',
-                                desc=('Specifies the data type of the input file: "char", "short", "int", "long",'
-                                     '"float" or "double". The input file must have BIG-ENDIAN ordering.'
-                                     'By default, the input type is "float".'))
+    inputdatatype = traits.Enum(
+        'float',
+        'char',
+        'short',
+        'int',
+        'long',
+        'double',
+        argstr='-inputdatatype %s',
+        desc=
+        ('Specifies the data type of the input file: "char", "short", "int", "long",'
+         '"float" or "double". The input file must have BIG-ENDIAN ordering.'
+         'By default, the input type is "float".'))
+
 
 class MESDOutputSpec(TraitedSpec):
     mesd_data = File(exists=True, desc='MESD data')
 
+
 class MESD(StdOutCommandLine):
     """
     MESD is a general program for maximum entropy spherical deconvolution.
@@ -273,8 +341,8 @@ class MESD(StdOutCommandLine):
     >>> mesd.run()            # doctest: +SKIP
     """
     _cmd = 'mesd'
-    input_spec=MESDInputSpec
-    output_spec=MESDOutputSpec
+    input_spec = MESDInputSpec
+    output_spec = MESDOutputSpec
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -282,62 +350,108 @@ class MESD(StdOutCommandLine):
         return outputs
 
     def _gen_outfilename(self):
-        _, name , _ = split_filename(self.inputs.scheme_file)
+        _, name, _ = split_filename(self.inputs.scheme_file)
         return name + '_MESD.Bdouble'
 
+
 class SFPeaksInputSpec(StdOutCommandLineInputSpec):
-    in_file = File(exists=True, argstr='-inputfile %s', mandatory=True,
-                   desc='Voxel-order data of spherical functions')
-    inputmodel = traits.Enum('sh', 'maxent', 'rbf', argstr='-inputmodel %s', mandatory=True,
-                             desc=('Type of functions input via in_file. Currently supported options are: '
-                                   '  sh - Spherical harmonic series. Specify the maximum order of the SH series '
-                                   '       with the "order" attribute if different from the default of 4. '
-                                   '  maxent - Maximum entropy representations output by MESD. The reconstruction '
-                                   '           directions input to MESD must be specified. By default this is the '
-                                   '           same set of gradient directions (excluding zero gradients) in the '
-                                   '           scheme file, so specify the "schemefile" attribute unless the '
-                                   '           "mepointset" attribute was set in MESD. '
-                                   '  rbf - Sums of radial basis functions. Specify the pointset with the attribute '
-                                   '        "rbfpointset" if different from the default. See QBallMX.'))
-    order = traits.Int(argstr='-order %d', units='NA',
-                       desc='Specific to sh. Maximum order of the spherical harmonic series.')
-    scheme_file = File(exists=True, argstr='%s',
-                       desc='Specific to maxent. Specifies the scheme file.')
-    rbfpointset = traits.Int(argstr='-rbfpointset %d', units='NA',
-                             desc=('Specific to rbf. Sets the number of radial basis functions to use. '
-                                   'The value specified must be present in the Pointsets directory. '
-                                   'The default value is 246.'))
-    mepointset = traits.Int(argstr='-mepointset %d', units='NA',
-                            desc=('Use a set of directions other than those in the scheme file for the deconvolution '
-                                 'kernel. The number refers to the number of directions on the unit sphere. '
-                                 'For example, "mepointset = 54" uses the directions in "camino/PointSets/Elec054.txt" '
-                                 'Use this option only if you told MESD to use a custom set of directions with the same '
-                                 'option. Otherwise, specify the scheme file with the "schemefile" attribute.'))
-    numpds = traits.Int(argstr='-numpds %d', units='NA',
-                        desc='The largest number of peak directions to output in each voxel.')
-    noconsistencycheck = traits.Bool(argstr='-noconsistencycheck',
-                                     desc='Turns off the consistency check. The output shows all consistencies as true.')
-    searchradius = traits.Float(argstr='-searchradius %f', units='NA',
-                                desc='The search radius in the peak finding algorithm. The default is 0.4 (cf. "density")')
-    density = traits.Int(argstr='-density %d', units='NA',
-                         desc=('The  number  of  randomly  rotated icosahedra to use in constructing the set of points for '
-                               'random sampling in the peak finding algorithm. Default is 1000, which works well for very '
-                               'spiky maxent functions. For other types of function, it is reasonable to set the density '
-                               'much lower and increase the search radius slightly, which speeds up the computation.'))
-    pointset = traits.Int(argstr='-pointset %d', units='NA',
-                          desc=('To sample using an evenly distributed set of points instead. The integer can be '
-                                '0, 1, ..., 7. Index 0 gives 1082 points, 1 gives 1922, 2 gives 3002, 3 gives 4322, '
-                                '4 gives 5882, 5 gives 8672, 6 gives 12002, 7 gives 15872.'))
-    pdthresh = traits.Float(argstr='-pdthresh %f', units='NA',
-                            desc=('Base threshold on the actual peak direction strength divided by the mean of the '
-                                  'function.  The default is 1.0 (the peak must be equal or greater than the mean).'))
-    stdsfrommean = traits.Float(argstr='-stdsfrommean %f', units='NA',
-                            desc=('This is the number of standard deviations of the function to be added to the '
-                                 '"pdthresh" attribute in the peak directions pruning.'))
+    in_file = File(
+        exists=True,
+        argstr='-inputfile %s',
+        mandatory=True,
+        desc='Voxel-order data of spherical functions')
+    inputmodel = traits.Enum(
+        'sh',
+        'maxent',
+        'rbf',
+        argstr='-inputmodel %s',
+        mandatory=True,
+        desc=
+        ('Type of functions input via in_file. Currently supported options are: '
+         '  sh - Spherical harmonic series. Specify the maximum order of the SH series '
+         '       with the "order" attribute if different from the default of 4. '
+         '  maxent - Maximum entropy representations output by MESD. The reconstruction '
+         '           directions input to MESD must be specified. By default this is the '
+         '           same set of gradient directions (excluding zero gradients) in the '
+         '           scheme file, so specify the "schemefile" attribute unless the '
+         '           "mepointset" attribute was set in MESD. '
+         '  rbf - Sums of radial basis functions. Specify the pointset with the attribute '
+         '        "rbfpointset" if different from the default. See QBallMX.'))
+    order = traits.Int(
+        argstr='-order %d',
+        units='NA',
+        desc='Specific to sh. Maximum order of the spherical harmonic series.')
+    scheme_file = File(
+        exists=True,
+        argstr='%s',
+        desc='Specific to maxent. Specifies the scheme file.')
+    rbfpointset = traits.Int(
+        argstr='-rbfpointset %d',
+        units='NA',
+        desc=(
+            'Specific to rbf. Sets the number of radial basis functions to use. '
+            'The value specified must be present in the Pointsets directory. '
+            'The default value is 246.'))
+    mepointset = traits.Int(
+        argstr='-mepointset %d',
+        units='NA',
+        desc=
+        ('Use a set of directions other than those in the scheme file for the deconvolution '
+         'kernel. The number refers to the number of directions on the unit sphere. '
+         'For example, "mepointset = 54" uses the directions in "camino/PointSets/Elec054.txt" '
+         'Use this option only if you told MESD to use a custom set of directions with the same '
+         'option. Otherwise, specify the scheme file with the "schemefile" attribute.'
+         ))
+    numpds = traits.Int(
+        argstr='-numpds %d',
+        units='NA',
+        desc='The largest number of peak directions to output in each voxel.')
+    noconsistencycheck = traits.Bool(
+        argstr='-noconsistencycheck',
+        desc=
+        'Turns off the consistency check. The output shows all consistencies as true.'
+    )
+    searchradius = traits.Float(
+        argstr='-searchradius %f',
+        units='NA',
+        desc=
+        'The search radius in the peak finding algorithm. The default is 0.4 (cf. "density")'
+    )
+    density = traits.Int(
+        argstr='-density %d',
+        units='NA',
+        desc=
+        ('The  number  of  randomly  rotated icosahedra to use in constructing the set of points for '
+         'random sampling in the peak finding algorithm. Default is 1000, which works well for very '
+         'spiky maxent functions. For other types of function, it is reasonable to set the density '
+         'much lower and increase the search radius slightly, which speeds up the computation.'
+         ))
+    pointset = traits.Int(
+        argstr='-pointset %d',
+        units='NA',
+        desc=
+        ('To sample using an evenly distributed set of points instead. The integer can be '
+         '0, 1, ..., 7. Index 0 gives 1082 points, 1 gives 1922, 2 gives 3002, 3 gives 4322, '
+         '4 gives 5882, 5 gives 8672, 6 gives 12002, 7 gives 15872.'))
+    pdthresh = traits.Float(
+        argstr='-pdthresh %f',
+        units='NA',
+        desc=
+        ('Base threshold on the actual peak direction strength divided by the mean of the '
+         'function.  The default is 1.0 (the peak must be equal or greater than the mean).'
+         ))
+    stdsfrommean = traits.Float(
+        argstr='-stdsfrommean %f',
+        units='NA',
+        desc=
+        ('This is the number of standard deviations of the function to be added to the '
+         '"pdthresh" attribute in the peak directions pruning.'))
+
 
 class SFPeaksOutputSpec(TraitedSpec):
     peaks = File(exists=True, desc='Peaks of the spherical functions.')
 
+
 class SFPeaks(StdOutCommandLine):
     """
     Finds the peaks of spherical functions.
@@ -417,8 +531,8 @@ class SFPeaks(StdOutCommandLine):
     >>> sf_peaks.run()          # doctest: +SKIP
     """
     _cmd = 'sfpeaks'
-    input_spec=SFPeaksInputSpec
-    output_spec=SFPeaksOutputSpec
+    input_spec = SFPeaksInputSpec
+    output_spec = SFPeaksOutputSpec
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -426,7 +540,5 @@ class SFPeaks(StdOutCommandLine):
         return outputs
 
     def _gen_outfilename(self):
-        _, name , _ = split_filename(self.inputs.in_file)
+        _, name, _ = split_filename(self.inputs.in_file)
         return name + '_peaks.Bdouble'
-
-
