@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """The fsl module provides classes for interfacing with the `FSL
@@ -24,57 +25,51 @@ Examples
 See the docstrings of the individual classes for examples.
 
 """
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 from glob import glob
 import os
-import warnings
 
-from ...utils.filemanip import fname_presuffix, split_filename, copyfile
-from ..base import (traits, isdefined,
-                    CommandLine, CommandLineInputSpec, TraitedSpec,
-                    File, Directory, InputMultiPath, OutputMultiPath)
+from ... import logging
+from ...utils.filemanip import fname_presuffix
+from ..base import (traits, isdefined, CommandLine, CommandLineInputSpec,
+                    PackageInfo)
+from ...external.due import BibTeX
 
-warn = warnings.warn
-warnings.filterwarnings('always', category=UserWarning)
+IFLOGGER = logging.getLogger('nipype.interface')
 
 
-class Info(object):
-    """Handle fsl output type and version information.
-
-    version refers to the version of fsl on the system
+class Info(PackageInfo):
+    """
+    Handle FSL ``output_type`` and version information.
 
     output type refers to the type of file fsl defaults to writing
     eg, NIFTI, NIFTI_GZ
 
+    Examples
+    --------
+
+    >>> from nipype.interfaces.fsl import Info
+    >>> Info.version()  # doctest: +SKIP
+    >>> Info.output_type()  # doctest: +SKIP
+
+
     """
 
-    ftypes = {'NIFTI': '.nii',
-              'NIFTI_PAIR': '.img',
-              'NIFTI_GZ': '.nii.gz',
-              'NIFTI_PAIR_GZ': '.img.gz'}
+    ftypes = {
+        'NIFTI': '.nii',
+        'NIFTI_PAIR': '.img',
+        'NIFTI_GZ': '.nii.gz',
+        'NIFTI_PAIR_GZ': '.img.gz'
+    }
+
+    if os.getenv('FSLDIR'):
+        version_file = os.path.join(os.getenv('FSLDIR'), 'etc', 'fslversion')
 
     @staticmethod
-    def version():
-        """Check for fsl version on system
-
-        Parameters
-        ----------
-        None
-
-        Returns
-        -------
-        version : str
-           Version number as string or None if FSL not found
-
-        """
-        # find which fsl being used....and get version from
-        # /path/to/fsl/etc/fslversion
-        try:
-            basedir = os.environ['FSLDIR']
-        except KeyError:
-            return None
-        out = open('%s/etc/fslversion' % (basedir)).read()
-        return out.strip('\n')
+    def parse_version(raw_info):
+        return raw_info.splitlines()[0]
 
     @classmethod
     def output_type_to_ext(cls, output_type):
@@ -112,8 +107,8 @@ class Info(object):
         try:
             return os.environ['FSLOUTPUTTYPE']
         except KeyError:
-            warnings.warn(('FSL environment variables not set. setting output '
-                           'type to NIFTI'))
+            IFLOGGER.warn('FSLOUTPUTTYPE environment variable is not set. '
+                          'Setting FSLOUTPUTTYPE=NIFTI')
             return 'NIFTI'
 
     @staticmethod
@@ -129,8 +124,10 @@ class Info(object):
             raise Exception('FSL environment variables not set')
         stdpath = os.path.join(fsldir, 'data', 'standard')
         if img_name is None:
-            return [filename.replace(stdpath + '/', '')
-                    for filename in glob(os.path.join(stdpath, '*nii*'))]
+            return [
+                filename.replace(stdpath + '/', '')
+                for filename in glob(os.path.join(stdpath, '*nii*'))
+            ]
         return os.path.join(stdpath, img_name)
 
 
@@ -145,8 +142,8 @@ class FSLCommandInputSpec(CommandLineInputSpec):
     -------
     fsl.ExtractRoi(tmin=42, tsize=1, output_type='NIFTI')
     """
-    output_type = traits.Enum('NIFTI', Info.ftypes.keys(),
-                              desc='FSL output type')
+    output_type = traits.Enum(
+        'NIFTI', list(Info.ftypes.keys()), desc='FSL output type')
 
 
 class FSLCommand(CommandLine):
@@ -157,6 +154,20 @@ class FSLCommand(CommandLine):
     input_spec = FSLCommandInputSpec
     _output_type = None
 
+    references_ = [{
+        'entry':
+        BibTeX('@article{JenkinsonBeckmannBehrensWoolrichSmith2012,'
+               'author={M. Jenkinson, C.F. Beckmann, T.E. Behrens, '
+               'M.W. Woolrich, and S.M. Smith},'
+               'title={FSL},'
+               'journal={NeuroImage},'
+               'volume={62},'
+               'pages={782-790},'
+               'year={2012},'
+               '}'),
+        'tags': ['implementation'],
+    }]
+
     def __init__(self, **inputs):
         super(FSLCommand, self).__init__(**inputs)
         self.inputs.on_trait_change(self._output_update, 'output_type')
@@ -192,7 +203,11 @@ class FSLCommand(CommandLine):
     def version(self):
         return Info.version()
 
-    def _gen_fname(self, basename, cwd=None, suffix=None, change_ext=True,
+    def _gen_fname(self,
+                   basename,
+                   cwd=None,
+                   suffix=None,
+                   change_ext=True,
                    ext=None):
         """Generate a filename based on the given parameters.
 
@@ -234,8 +249,8 @@ class FSLCommand(CommandLine):
                 suffix = ext
         if suffix is None:
             suffix = ''
-        fname = fname_presuffix(basename, suffix=suffix,
-                                use_ext=False, newpath=cwd)
+        fname = fname_presuffix(
+            basename, suffix=suffix, use_ext=False, newpath=cwd)
         return fname
 
     def _overload_extension(self, value, name=None):
@@ -263,4 +278,5 @@ def no_fsl():
 
 def no_fsl_course_data():
     """check if fsl_course data is present"""
-    return not ('FSL_COURSE_DATA' in os.environ and os.path.isdir(os.path.abspath(os.environ['FSL_COURSE_DATA'])))
+    return not ('FSL_COURSE_DATA' in os.environ and os.path.isdir(
+        os.path.abspath(os.environ['FSL_COURSE_DATA'])))
